# Traceotter Python SDK

Traceotter Python SDK is an observability layer for LLM applications and agents.
Capture traces, spans, tool calls, generations, and evaluations to debug, monitor, and improve AI systems with real production data.